import wx
from BusyAnimation import BusyAnimation
import os
from time import sleep
from subprocess import Popen, PIPE

class Demo(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, "BusyAnimation Demonstration", size=(320, 450))
        self.SetBackgroundColour("grey80")
        txt = wx.StaticText(self, -1, "Testing process for 30 seconds", pos=(20, 20))
        self.sbutton = wx.Button(self, -1, label='Load Busy', pos=(20, 60))
        self.Bind(wx.EVT_BUTTON, self.OnStart, self.sbutton)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)
        self.SetBackgroundColour('#556b2f')
        self.SetForegroundColour('#ffffff')
        self.Show()

    def OnStart(self, event):
        self.sbutton.Disable()

        # for this demonstration a linux sleep command is put onto the system and that pid is monitored
        if wx.Platform != "__WXMSW__":
            proc = Popen(['sleep', '30'],).pid
        else:
            proc = Popen(['ping', '-w', '30', '127.0.0.1'],).pid

        # a busy animation that will run until a specific process terminates and then cancel itself using a gif file

        self.busy = BusyAnimation(self, wx.ID_ANY, title="Busy", size = (260, 260), msg="Processing...", \
                                images = ['progress.gif',], \
                                speed=50, elapse=0, timer = -1, pid_lock=proc)
        wx.GetApp().Yield()
        while self.busy.IsRunning(): # Busy can be cancelled by clicking Frame Close
            sleep(.1)
            wx.GetApp().Yield()

        try:
            self.sbutton.Enable()
        except Exception:
            pass

    def OnQuit(self, event):
        try:
            if self.busy.IsRunning():
                self.busy.Stop()
        except Exception:
            pass
        self.Destroy()

if __name__ == '__main__':
    app = wx.App()
    frame = Demo(None)
    app.MainLoop()
